package com.ruoyi.voluntary.service;

import java.util.List;
import com.ruoyi.voluntary.domain.BusiAgents;

/**
 * 代理商Service接口
 *
 * @author voluntary
 * @date 2022-11-20
 */
public interface IBusiAgentsService
{
    /**
     * 查询代理商
     *
     * @param agentId 代理商主键
     * @return 代理商
     */
    public BusiAgents selectBusiAgentsByAgentId(Long agentId);
    public BusiAgents selectBusiAgentsByUserId(Long userId);

    /**
     * 查询代理商列表
     *
     * @param busiAgents 代理商
     * @return 代理商集合
     */
    public List<BusiAgents> selectBusiAgentsList(BusiAgents busiAgents);

    /**
     * 新增代理商
     *
     * @param busiAgents 代理商
     * @return 结果
     */
    public int insertBusiAgents(BusiAgents busiAgents);

    /**
     * 修改代理商
     *
     * @param busiAgents 代理商
     * @return 结果
     */
    public int updateBusiAgents(BusiAgents busiAgents);

    /**
     * 批量删除代理商
     *
     * @param agentIds 需要删除的代理商主键集合
     * @return 结果
     */
    public int deleteBusiAgentsByAgentIds(Long[] agentIds);

    /**
     * 删除代理商信息
     *
     * @param agentId 代理商主键
     * @return 结果
     */
    public int deleteBusiAgentsByAgentId(Long agentId);
}
